<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru">
<context>
    <name>AmmoSchemeModel</name>
    <message>
        <source>new</source>
        <translation>новый</translation>
    </message>
    <message>
        <source>copy of</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FreqSpinBox</name>
    <message>
        <source>Never</source>
        <translation>Никогда</translation>
    </message>
    <message numerus="yes">
        <source>Every %1 turn</source>
        <translation>
            <numerusform>Каждый %1 ход</numerusform>
            <numerusform>Каждые %1 хода</numerusform>
            <numerusform>Каждые %1 ходов</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>GameCFGWidget</name>
    <message>
        <source>Edit weapons</source>
        <translation>Редактировать оружие</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <source>Illegal ammo scheme</source>
        <translation>Неправильный набор оружия</translation>
    </message>
    <message>
        <source>Edit schemes</source>
        <translation>Редактировать схемы</translation>
    </message>
    <message>
        <source>When this option is enabled selecting a game scheme will auto-select a weapon (and viceversa)</source>
        <translation type="obsolete">При включении этой опции выбор настроек игры автоматически выберет схему оружия (и наоборот)</translation>
    </message>
    <message>
        <source>When this option is enabled selecting a game scheme will auto-select a weapon</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HWChatWidget</name>
    <message>
        <source>%1 *** %2 has been removed from your ignore list</source>
        <translation>%1 *** %2 был удалён из вашего списка игнорирования</translation>
    </message>
    <message>
        <source>%1 *** %2 has been added to your ignore list</source>
        <translation>%1 *** %2 был добавлен в ваш список игнорирования</translation>
    </message>
    <message>
        <source>%1 *** %2 has been removed from your friends list</source>
        <translation>%1 *** %2 был удалён из вашего списка друзей</translation>
    </message>
    <message>
        <source>%1 *** %2 has been added to your friends list</source>
        <translation>%1 *** %2 был добавлен в ваш список друзей</translation>
    </message>
</context>
<context>
    <name>HWForm</name>
    <message>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>ОК</translation>
    </message>
    <message>
        <source>Cannot save record to file %1</source>
        <translation>Не могу сохранить запись в файл %1</translation>
    </message>
    <message>
        <source>Unable to start the server</source>
        <translation>Ошибка запуска сервера</translation>
    </message>
    <message>
        <source>new</source>
        <translation type="obsolete">новый</translation>
    </message>
    <message>
        <source>Please select record from the list above</source>
        <translation>Выберите запись из списка</translation>
    </message>
    <message>
        <source>DefaultTeam</source>
        <translation>Команда по умолчанию</translation>
    </message>
    <message>
        <source>Hedgewars Demo File</source>
        <comment>File Types</comment>
        <translation>Файл записи игры hedgewars</translation>
    </message>
    <message>
        <source>Hedgewars Save File</source>
        <comment>File Types</comment>
        <translation>Файл сохранения игры hedgewars</translation>
    </message>
</context>
<context>
    <name>HWGame</name>
    <message>
        <source>en.txt</source>
        <translation>ru.txt</translation>
    </message>
    <message>
        <source>Cannot open demofile %1</source>
        <translation>Не могу открыть демо %1</translation>
    </message>
</context>
<context>
    <name>HWMapContainer</name>
    <message>
        <source>Map</source>
        <translation>Карта</translation>
    </message>
    <message>
        <source>Themes</source>
        <translation>Темы</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Фильтр</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Все</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>Маленькие</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Средние</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>Большие</translation>
    </message>
    <message>
        <source>Cavern</source>
        <translation>Пещеры</translation>
    </message>
    <message>
        <source>Wacky</source>
        <translation>Необычные</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Тип</translation>
    </message>
    <message>
        <source>Small tunnels</source>
        <translation>Маленькие туннели</translation>
    </message>
    <message>
        <source>Medium tunnels</source>
        <translation>Средние туннели</translation>
    </message>
    <message>
        <source>Large tunnels</source>
        <translation>Большие туннели</translation>
    </message>
    <message>
        <source>Small floating islands</source>
        <translation>Маленькие островки</translation>
    </message>
    <message>
        <source>Medium floating islands</source>
        <translation>Средние островки</translation>
    </message>
    <message>
        <source>Large floating islands</source>
        <translation>Большие островки</translation>
    </message>
    <message>
        <source>Seed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HWNetServersModel</name>
    <message>
        <source>Title</source>
        <translation>Название</translation>
    </message>
    <message>
        <source>IP</source>
        <translation>IP</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Порт</translation>
    </message>
</context>
<context>
    <name>HWNewNet</name>
    <message>
        <source>The host was not found. Please check the host name and port settings.</source>
        <translation>Ошибка подключения. Проверьте имя сервера и номер порта.</translation>
    </message>
    <message>
        <source>Connection refused</source>
        <translation>Отказано в соединении</translation>
    </message>
    <message>
        <source>Quit reason: </source>
        <translation>Вышел: </translation>
    </message>
    <message>
        <source>Room destroyed</source>
        <translation>Комната удалена</translation>
    </message>
    <message>
        <source>You got kicked</source>
        <translation>Вас выкинули</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Пароль</translation>
    </message>
    <message>
        <source>Your nickname %1 is
registered on Hedgewars.org
Please provide your password
or pick another nickname:</source>
        <translation type="obsolete">Ваш псевдоним %1 уже
зарегистрирован на сайте Hedgewars.org
Пожалуйста, укажите ваш пароль
или выберите другой псевдоним:</translation>
    </message>
    <message>
        <source>%1 *** %2 has joined the room</source>
        <translation>%1 *** %2 вошёл в комнату</translation>
    </message>
    <message>
        <source>%1 *** %2 has joined</source>
        <translation>%1 *** %2 вошёл</translation>
    </message>
    <message>
        <source>%1 *** %2 has left (%3)</source>
        <translation>%1 *** %2 ушёл (%3)</translation>
    </message>
    <message>
        <source>%1 *** %2 has left</source>
        <translation>%1 *** %2 ушёл</translation>
    </message>
    <message>
        <source>Your nickname %1 is
registered on Hedgewars.org
Please provide your password below
or pick another nickname in game config:</source>
        <translation>Ваше имя пользователя %1 
зарегистрировано на сайте hedgewars.org
Пожалуйста, укажите ваш пароль в поле ввода внизу
или выберите иное имя пользователя в настройках игры:</translation>
    </message>
</context>
<context>
    <name>KB</name>
    <message>
        <source>SDL_ttf returned error while rendering text, most propably it is related to the bug in freetype2. It&apos;s recommended to update your freetype lib.</source>
        <translation>SDL_ttf возвратил ошибку при выводе текста, наиболее вероятно это вызвано багом в библиотеке freetype2. Рекомендуется обновить библиотеку.</translation>
    </message>
</context>
<context>
    <name>PageAdmin</name>
    <message>
        <source>Server message:</source>
        <translation type="obsolete">Сообщение сервера:</translation>
    </message>
    <message>
        <source>Set message</source>
        <translation type="obsolete">Установить сообщение</translation>
    </message>
    <message>
        <source>Clear Accounts Cache</source>
        <translation>Очистить кэш учётных записей</translation>
    </message>
    <message>
        <source>Fetch data</source>
        <translation>Получить данные</translation>
    </message>
    <message>
        <source>Server message for latest version:</source>
        <translation>Сообщение сервера для последней версии клиента:</translation>
    </message>
    <message>
        <source>Server message for previous versions:</source>
        <translation>Сообщение сервера для предыдущих версий клиента:</translation>
    </message>
    <message>
        <source>Latest version protocol number:</source>
        <translation>Номер протокола последнего релиза:</translation>
    </message>
    <message>
        <source>MOTD preview:</source>
        <translation>Предпросмотр сообщения сервера:</translation>
    </message>
    <message>
        <source>Set data</source>
        <translation>Установить данные</translation>
    </message>
</context>
<context>
    <name>PageConnecting</name>
    <message>
        <source>Connecting...</source>
        <translation>Соединение...</translation>
    </message>
</context>
<context>
    <name>PageDrawMap</name>
    <message>
        <source>Undo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear</source>
        <translation type="unfinished">Очистить</translation>
    </message>
    <message>
        <source>Load</source>
        <translation type="unfinished">Загрузить</translation>
    </message>
    <message>
        <source>Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Load drawn map</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Drawn Maps (*.hwmap);;All files (*.*)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save drawn map</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageEditTeam</name>
    <message>
        <source>General</source>
        <translation>Основные настройки</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>Дополнительно</translation>
    </message>
</context>
<context>
    <name>PageGameStats</name>
    <message>
        <source>&lt;p&gt;The best shot award was won by &lt;b&gt;%1&lt;/b&gt; with &lt;b&gt;%2&lt;/b&gt; pts.&lt;/p&gt;</source>
        <translation type="obsolete">&lt;p&gt;Приз за лучший выстрел получает &lt;b&gt;%1&lt;/b&gt; с &lt;b&gt;%2&lt;/b&gt; пунктами урона.&lt;/p&gt;</translation>
    </message>
    <message numerus="yes">
        <source>&lt;p&gt;The best killer is &lt;b&gt;%1&lt;/b&gt; with &lt;b&gt;%2&lt;/b&gt; kills in a turn.&lt;/p&gt;</source>
        <translation type="obsolete">
            <numerusform>&lt;p&gt;Лучший киллер ‒ это &lt;b&gt;%1&lt;/b&gt; с &lt;b&gt;%2&lt;/b&gt; убитым за ход.&lt;/p&gt;</numerusform>
            <numerusform>&lt;p&gt;Лучший киллер ‒ это &lt;b&gt;%1&lt;/b&gt; с &lt;b&gt;%2&lt;/b&gt; убитыми за ход.&lt;/p&gt;</numerusform>
            <numerusform>&lt;p&gt;Лучший киллер ‒ это &lt;b&gt;%1&lt;/b&gt; с &lt;b&gt;%2&lt;/b&gt; убитыми за ход.&lt;/p&gt;</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>&lt;p&gt;A total of &lt;b&gt;%1&lt;/b&gt; hedgehog(s) were killed during this round.&lt;/p&gt;</source>
        <translation type="obsolete">
            <numerusform>&lt;p&gt;Всего &lt;b&gt;%1&lt;/b&gt; ёж был убит за этот поединок.&lt;/p&gt;</numerusform>
            <numerusform>&lt;p&gt;Всего &lt;b&gt;%1&lt;/b&gt; ежа были убиты за этот поединок.&lt;/p&gt;</numerusform>
            <numerusform>&lt;p&gt;Всего &lt;b&gt;%1&lt;/b&gt; ежей были убиты за этот поединок.&lt;/p&gt;</numerusform>
        </translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Подробности</translation>
    </message>
    <message>
        <source>Health graph</source>
        <translation>График уровня здоровья</translation>
    </message>
    <message>
        <source>Ranking</source>
        <translation>Рейтинг</translation>
    </message>
    <message>
        <source>The best shot award was won by &lt;b&gt;%1&lt;/b&gt; with &lt;b&gt;%2&lt;/b&gt; pts.</source>
        <translation>Приз за лучший выстрел получает &lt;b&gt;%1&lt;/b&gt; с &lt;b&gt;%2&lt;/b&gt; пунктами урона.</translation>
    </message>
    <message numerus="yes">
        <source>The best killer is &lt;b&gt;%1&lt;/b&gt; with &lt;b&gt;%2&lt;/b&gt; kills in a turn.</source>
        <translation>
            <numerusform>Лучший убийца &lt;b&gt;%1&lt;/b&gt; с &lt;b&gt;%2&lt;/b&gt; убийством за ход.</numerusform>
            <numerusform>Лучший убийца &lt;b&gt;%1&lt;/b&gt; с &lt;b&gt;%2&lt;/b&gt; убийствами за ход.</numerusform>
            <numerusform>Лучший убийца &lt;b&gt;%1&lt;/b&gt; с &lt;b&gt;%2&lt;/b&gt; убийствами за ход.</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>A total of &lt;b&gt;%1&lt;/b&gt; hedgehog(s) were killed during this round.</source>
        <translation>
            <numerusform>Всего &lt;b&gt;%1&lt;/b&gt; ёж был убит в течение игры.</numerusform>
            <numerusform>Всего &lt;b&gt;%1&lt;/b&gt; ежа были убиты в течение игры.</numerusform>
            <numerusform>Всего &lt;b&gt;%1&lt;/b&gt; ежей были убиты в течение игры.</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>(%1 kill)</source>
        <translation>
            <numerusform>(%1 убийство)</numerusform>
            <numerusform>(%1 убийства)</numerusform>
            <numerusform>(%1 убийств)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>&lt;b&gt;%1&lt;/b&gt; thought it&apos;s good to shoot his own hedgehogs with &lt;b&gt;%2&lt;/b&gt; pts.</source>
        <translation>
            <numerusform>&lt;b&gt;%1&lt;/b&gt; посчитал нужным подстрелить друзей на &lt;b&gt;%2&lt;/b&gt; пункт урона.</numerusform>
            <numerusform>&lt;b&gt;%1&lt;/b&gt; посчитал нужным подстрелить друзей на &lt;b&gt;%2&lt;/b&gt; пункта урона.</numerusform>
            <numerusform>&lt;b&gt;%1&lt;/b&gt; посчитал нужным подстрелить друзей на &lt;b&gt;%2&lt;/b&gt; пунктов урона.</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>&lt;b&gt;%1&lt;/b&gt; killed &lt;b&gt;%2&lt;/b&gt; of his own hedgehogs.</source>
        <translation>
            <numerusform>&lt;b&gt;%1&lt;/b&gt; убил &lt;b&gt;%2&lt;/b&gt; союзника.</numerusform>
            <numerusform>&lt;b&gt;%1&lt;/b&gt; убил &lt;b&gt;%2&lt;/b&gt; союзников.</numerusform>
            <numerusform>&lt;b&gt;%1&lt;/b&gt; убил &lt;b&gt;%2&lt;/b&gt; союзников.</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>&lt;b&gt;%1&lt;/b&gt; was scared and skipped turn &lt;b&gt;%2&lt;/b&gt; times.</source>
        <translation>
            <numerusform>&lt;b&gt;%1&lt;/b&gt; испугался и пропустил &lt;b&gt;%2&lt;/b&gt; ход.</numerusform>
            <numerusform>&lt;b&gt;%1&lt;/b&gt; испугался и пропустил &lt;b&gt;%2&lt;/b&gt; хода.</numerusform>
            <numerusform>&lt;b&gt;%1&lt;/b&gt; испугался и пропустил &lt;b&gt;%2&lt;/b&gt; ходов.</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>PageMain</name>
    <message>
        <source>Local Game (Play a game on a single computer)</source>
        <translation>Локальная игра (игра на одном компьютере)</translation>
    </message>
    <message>
        <source>Network Game (Play a game across a network)</source>
        <translation>Сетевая игра</translation>
    </message>
    <message>
        <source>Simply pick the same color as a friend to play together as a team. Each of you will still control his or her own hedgehogs but they&apos;ll win or lose together.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Some weapons might do only low damage but they can be a lot more devastating in the right situation. Try to use the Desert Eagle to knock multiple hedgehogs into the water.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If you&apos;re unsure what to do and don&apos;t want to waste ammo, skip one round. But don&apos;t let too much time pass as there will be Sudden Death!</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If you&apos;d like to keep others from using your preferred nickname on the official server, register an account at http://www.hedgewars.org/.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You&apos;re bored of default gameplay? Try one of the missions - they&apos;ll offer different gameplay depending on the one you picked.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>By default the game will always record the last game played as a demo. Select &apos;Local Game&apos; and pick the &apos;Demos&apos; button on the lower right corner to play or manage them.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hedgewars is Open Source and Freeware we create in our spare time. If you&apos;ve got problems, ask on our forums but please don&apos;t expect 24/7 support!</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hedgewars is Open Source and Freeware we create in our spare time. If you like it, help us with a small donation or contribute your own work!</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hedgewars is Open Source and Freeware we create in our spare time. Share it with your family and friends as you like!</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>From time to time there will be official tournaments. Upcoming events will be announced at http://www.hedgewars.org/ some days in advance.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hedgewars is available in many languages. If the translation in your language seems to be missing or outdated, feel free to contact us!</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hedgewars can be run on lots of different operating systems including Microsoft Windows, Mac OS X and Linux.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Always remember you&apos;re able to set up your own games in local and network/online play. You&apos;re not restricted to the &apos;Simple Game&apos; option.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>While playing you should give yourself a short break at least once an hour.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If your graphics card isn&apos;t able to provide hardware accelerated OpenGL, try to enable the low quality mode to improve performance.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>We&apos;re open to suggestions and constructive feedback. If you don&apos;t like something or got a great idea, let us know!</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Especially while playing online be polite and always remember there might be some minors playing with or against you as well!</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Special game modes such as &apos;Vampirism&apos; or &apos;Karma&apos; allow you to develop completely new tactics. Try them in a custom game!</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The Windows version of Hedgewars supports Xfire. Make sure to add Hedgwars to its game list so your friends can see you playing.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You should never install Hedgewars on computers you don&apos;t own (school, university, work, etc.). Please ask the responsible person instead!</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hedgewars can be perfect for short games during breaks. Just ensure you don&apos;t add too many hedgehogs or use an huge map. Reducing time and health might help as well.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No hedgehogs were harmed in making this game.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hedgewars is Open Source and Freeware we create in our spare time. If someone sold you the game, you should try get a refund!</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Connect one or more gamepads before starting the game to be able to assign their controls to your teams.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Create an account on %1 to keep others from using your most favourite nickname while playing on the official server.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If your graphics card isn&apos;t able to provide hardware accelerated OpenGL, try to update the associated drivers.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>There are three different jumps available. Tap [high jump] twice to do a very high/backwards jump.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Afraid of falling off a cliff? Hold down [precise] to turn [left] or [right] without actually moving.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Some weapons require special strategies or just lots of training, so don&apos;t give up on a particular tool if you miss an enemy once.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Most weapons won&apos;t work once they touch the water. The Homing Bee as well as the Cake are exceptions to this.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The Old Limbuger only causes a small explosion. However the wind affected smelly cloud can poison lots of hogs at once.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The Piano Strike is the most damaging air strike. You&apos;ll lose the hedgehog performing it, so there&apos;s a huge downside as well.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The Homing Bee can be tricky to use. It&apos;s turn radius depends on it&apos;s velocity, so try to not use full power.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sticky Mines are a perfect tool to create small chain reactions knocking enemy hedgehogs into dire situations ... or water.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The Hammer is most effective when used on bridges or girders. Hit hogs will just break through the ground.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If you&apos;re stuck behind an enemy hedgehog, use the Hammer to free yourself without getting damaged by an explosion.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The Cake&apos;s maximum walking distance depends on the ground it has to pass. Use [attack] to detonate it early.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The Flame Thrower is a weapon but it can be used for tunnel digging as well.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use the Incinerating Grenade to temporary keep hedgehogs from passing terrain such as tunnels or platforms.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Want to know who&apos;s behind the game? Click on the Hedgewars logo in the main menu to see the credits.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Like Hedgewars? Become a fan on %1 or follow us on %2!</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Feel free to draw your own graves, hats, flags or even maps and themes! But note that you&apos;ll have to share them somewhere to use them online.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Really want to wear a specific hat? Donate to us and receive an exclusive hat of your choice!</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Keep your video card drivers up to date to avoid issues playing the game.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can find your Hedgewars configuration files under &quot;My Documents\Hedgewars&quot;. Create backups or take the files with you, but don&apos;t edit them by hand.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You&apos;re able to associate Hedgewars related files (savegames and demo recordings) with the game to launch them right from your favorite file or internet browser.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Want to save ropes? Release the rope in mid air and then shoot again. As long as you don&apos;t touch the ground you&apos;ll reuse your rope without wasting ammo!</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can find your Hedgewars configuration files under &quot;Library/Application Support/Hedgewars&quot; in your home directory. Create backups or take the files with you, but don&apos;t edit them by hand.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can find your Hedgewars configuration files under &quot;.hedgewars&quot; in your home directory. Create backups or take the files with you, but don&apos;t edit them by hand.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageMultiplayer</name>
    <message>
        <source>Start</source>
        <translation>Старт</translation>
    </message>
</context>
<context>
    <name>PageNet</name>
    <message>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <source>Please select server from the list above</source>
        <translation>Выберите сервер из списка</translation>
    </message>
</context>
<context>
    <name>PageNetGame</name>
    <message>
        <source>Control</source>
        <translation>Управление</translation>
    </message>
</context>
<context>
    <name>PageNetType</name>
    <message>
        <source>LAN game</source>
        <translation>Игра в локальной сети</translation>
    </message>
    <message>
        <source>Official server</source>
        <translation>Официальный сервер</translation>
    </message>
</context>
<context>
    <name>PageOptions</name>
    <message>
        <source>New team</source>
        <translation>Новая команда</translation>
    </message>
    <message>
        <source>Edit team</source>
        <translation>Изменить</translation>
    </message>
    <message>
        <source>Delete team</source>
        <translation>Удалить команду</translation>
    </message>
    <message>
        <source>New weapon scheme</source>
        <translation type="obsolete">Новая схема оружия</translation>
    </message>
    <message>
        <source>Edit weapon scheme</source>
        <translation type="obsolete">Редактировать схему оружия</translation>
    </message>
    <message>
        <source>Delete weapon scheme</source>
        <translation type="obsolete">Удалить схему оружия</translation>
    </message>
    <message>
        <source>You can&apos;t edit teams from team selection. Go back to main menu to add, edit or delete teams.</source>
        <translation>Невозможно редактировать команды со страницы выбора команд. Вернитесь в главное меню для добавления, редактирования или удаления команд.</translation>
    </message>
    <message>
        <source>New scheme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit scheme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete scheme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New weapon set</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit weapon set</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete weapon set</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PagePlayDemo</name>
    <message>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>ОК</translation>
    </message>
    <message>
        <source>Rename dialog</source>
        <translation>Переименование</translation>
    </message>
    <message>
        <source>Enter new file name:</source>
        <translation>Введите новое имя файла:</translation>
    </message>
    <message>
        <source>Cannot rename to</source>
        <translation>Не могу переименовать в</translation>
    </message>
    <message>
        <source>Cannot delete file</source>
        <translation>Не могу удалить файл</translation>
    </message>
    <message>
        <source>Please select record from the list</source>
        <translation>Выберите запись из списка</translation>
    </message>
</context>
<context>
    <name>PageRoomsList</name>
    <message>
        <source>Create</source>
        <translation>Создать</translation>
    </message>
    <message>
        <source>Join</source>
        <translation>Присоединиться</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Обновить</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>ОК</translation>
    </message>
    <message>
        <source>Admin features</source>
        <translation>Администрирование</translation>
    </message>
    <message>
        <source>Room Name:</source>
        <translation>Название комнаты:</translation>
    </message>
    <message>
        <source>This game is in lobby.
You may join and start playing once the game starts.</source>
        <translation>В этой комнате игра ещё не запущена.
Вы можете зайти и присоединиться к игре.</translation>
    </message>
    <message>
        <source>This game is in progress.
You may join and spectate now but you&apos;ll have to wait for the game to end to start playing.</source>
        <translation>В этой комнате происходит игра.
Вы можете зайти и наблюдать. Чтобы играть, придётся подождать окончания текущей игры.</translation>
    </message>
    <message>
        <source>%1 is the host. He may adjust settings and start the game.</source>
        <translation>%1 управляет комнатой. Он может изменять настройки и запускать игру.</translation>
    </message>
    <message>
        <source>Random Map</source>
        <translation>Случайная карта</translation>
    </message>
    <message>
        <source>Games may be played on precreated or randomized maps.</source>
        <translation>Можно играть на нарисованных или сгенерированных картах.</translation>
    </message>
    <message>
        <source>The Game Scheme defines general options and preferences like Round Time, Sudden Death or Vampirism.</source>
        <translation>Схема игры определяет общие настройки, такие как время хода или вампиризм.</translation>
    </message>
    <message>
        <source>The Weapon Scheme defines available weapons and their ammunition count.</source>
        <translation>Схема оружия определяет доступное оружие и число снарядов.</translation>
    </message>
    <message numerus="yes">
        <source>There are %1 clients connected to this room.</source>
        <translation>
            <numerusform>Всего %1 игрок находится в этой комнате.</numerusform>
            <numerusform>Всего %1 игрока находятся в этой комнате.</numerusform>
            <numerusform>Всего %1 игроков находятся в этой комнате.</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>There are %1 teams participating in this room.</source>
        <translation>
            <numerusform>Всего %1 команда участвует в игре в этой комнате.</numerusform>
            <numerusform>Всего %1 команды участвуют в игре в этой комнате.</numerusform>
            <numerusform>Всего %1 команд участвуют в игре в этой комнате.</numerusform>
        </translation>
    </message>
    <message>
        <source>Please enter room name</source>
        <translation>Введите название комнаты</translation>
    </message>
    <message>
        <source>Please select room from the list</source>
        <translation>Выберите комнату из списка</translation>
    </message>
    <message>
        <source>Random Maze</source>
        <translation>Случайный лабиринт</translation>
    </message>
    <message>
        <source>State:</source>
        <translation>Состояние:</translation>
    </message>
    <message>
        <source>Rules:</source>
        <translation>Правила:</translation>
    </message>
    <message>
        <source>Weapons:</source>
        <translation>Оружие:</translation>
    </message>
    <message>
        <source>Search:</source>
        <translation>Поиск:</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Очистить</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Предупреждение</translation>
    </message>
    <message>
        <source>The game you are trying to join has started.
Do you still want to join the room?</source>
        <translation>Игра, к которой вы хотите присоединиться, уже началась
Вы всё равно хотите зайти в комнату?</translation>
    </message>
</context>
<context>
    <name>PageScheme</name>
    <message>
        <source>Enable random mines</source>
        <translation type="obsolete">Включить мины</translation>
    </message>
    <message>
        <source>Gain 80% of the damage you do back in health</source>
        <translation>80% урона, нанесённого врагу, вернётся в виде здоровья вашему ежу</translation>
    </message>
    <message>
        <source>Share your opponents pain, share their damage</source>
        <translation>Раздели боль врага, раздели с ним его урон</translation>
    </message>
    <message>
        <source>Your hogs are unable to move, put your artillery skills to the test</source>
        <translation>Ёжики не могут двигаться, проверьте свои артиллерийские навыки</translation>
    </message>
    <message>
        <source>Random</source>
        <translation>Случайно</translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation>Секунды</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Новая</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <source>Defend your fort and destroy the opponents, two team colours max!</source>
        <translation>Защищай свой форт и уничтожай форт оппонента, два цвета команды на карте!</translation>
    </message>
    <message>
        <source>Teams will start on opposite sides of the terrain, two team colours max!</source>
        <translation>Команды располагаются в противоположных сторонах карты, два цвета команды на карте!</translation>
    </message>
    <message>
        <source>Land can not be destroyed!</source>
        <translation>Земля не может быть разрушена!</translation>
    </message>
    <message>
        <source>Add an indestructable border around the terrain</source>
        <translation>Добавить неразрушимую границу вокруг карты</translation>
    </message>
    <message>
        <source>Lower gravity</source>
        <translation>Пониженная гравитация</translation>
    </message>
    <message>
        <source>Assisted aiming with laser sight</source>
        <translation>Помощь в прицеливании (лазерный прицел)</translation>
    </message>
    <message>
        <source>All hogs have a personal forcefield</source>
        <translation>Каждый ёжик в защитном поле</translation>
    </message>
    <message>
        <source>Order of play is random instead of in room order.</source>
        <translation>Порядок ходов случаен, а не является порядком команд в списке.</translation>
    </message>
    <message>
        <source>Play with a King. If he dies, your side dies.</source>
        <translation>Играть с Королём. Если он умирает, ваша сторона проигрывает.</translation>
    </message>
    <message>
        <source>Take turns placing your hedgehogs before the start of play.</source>
        <translation>Расставить ежей вручную перед игрой.</translation>
    </message>
    <message>
        <source>Ammo is shared between all teams that share a colour.</source>
        <translation>Оружие совместно используется всеми командами с одним цветом.</translation>
    </message>
    <message>
        <source>Disable girders when generating random maps.</source>
        <translation>Убрать балки из генерируемых карт.</translation>
    </message>
    <message>
        <source>Disable land objects when generating random maps.</source>
        <translation>Отключить добавляемые объекты на генерируемых картах.</translation>
    </message>
    <message>
        <source>AI respawns on death.</source>
        <translation>Боты воскресают после смерти.</translation>
    </message>
    <message>
        <source>All (living) hedgehogs are fully restored at the end of turn</source>
        <translation>Все (живые) ежи полностью поправляются в конце хода</translation>
    </message>
    <message>
        <source>Attacking does not end your turn.</source>
        <translation>Атака не заканчивает ход.</translation>
    </message>
    <message>
        <source>Weapons are reset to starting values each turn.</source>
        <translation>Набор оружия восстанавливается на каждом ходу.</translation>
    </message>
    <message>
        <source>Each hedgehog has its own ammo. It does not share with the team.</source>
        <translation>У каждого ежа свой набор оружия, не являющийся общим для команды.</translation>
    </message>
    <message>
        <source>You will not have to worry about wind anymore.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Wind will affect almost everything.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageSelectWeapon</name>
    <message>
        <source>Default</source>
        <translation>По умолчанию</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <source>New</source>
        <translation type="unfinished">Новая</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageSinglePlayer</name>
    <message>
        <source>Simple Game (a quick game against the computer, settings are chosen for you)</source>
        <translation>Быстрый старт (быстрый запуск игры против компьютера на случайной карте)</translation>
    </message>
    <message>
        <source>Multiplayer (play a hotseat game against your friends, or AI teams)</source>
        <translation>Схватка (игра с друзьями за одним компьютером или против ботов)</translation>
    </message>
    <message>
        <source>Training Mode (Practice your skills in a range of training missions). IN DEVELOPMENT</source>
        <translation>Тренировка (тренируйте своё мастерство в тренировочных миссиях) В РАЗРАБОТКЕ</translation>
    </message>
    <message>
        <source>Demos (Watch recorded demos)</source>
        <translation>Демки (просмотр записанных демок)</translation>
    </message>
    <message>
        <source>Load (Load a previously saved game)</source>
        <translation>Загрузить (загрузить сохранённую игру)</translation>
    </message>
    <message>
        <source>Campaign Mode (...). IN DEVELOPMENT</source>
        <translation>Режим прохождения кампании. В РАЗРАБОТКЕ</translation>
    </message>
</context>
<context>
    <name>QAction</name>
    <message>
        <source>Kick</source>
        <translation>Выпнуть</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Старт</translation>
    </message>
    <message>
        <source>Restrict Joins</source>
        <translation>Запретить вход</translation>
    </message>
    <message>
        <source>Restrict Team Additions</source>
        <translation>Запретить добавление команд</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Инфо</translation>
    </message>
    <message>
        <source>Ban</source>
        <translation>Заблокировать</translation>
    </message>
    <message>
        <source>Follow</source>
        <translation>Следовать</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Игнорировать</translation>
    </message>
    <message>
        <source>Add friend</source>
        <translation>Добавить в друзья</translation>
    </message>
    <message>
        <source>Unignore</source>
        <translation>Убрать игнорирование</translation>
    </message>
    <message>
        <source>Remove friend</source>
        <translation>Убирать из списка друзей</translation>
    </message>
</context>
<context>
    <name>QCheckBox</name>
    <message>
        <source>Check for updates at startup</source>
        <translation>Проверять обновления при запуске</translation>
    </message>
    <message>
        <source>Enable sound</source>
        <translation>Включить звук</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Полный экран</translation>
    </message>
    <message>
        <source>Show FPS</source>
        <translation>Показывать значение FPS</translation>
    </message>
    <message>
        <source>Alternative damage show</source>
        <translation>Альтернативный показ урона</translation>
    </message>
    <message>
        <source>Enable music</source>
        <translation>Включить музыку</translation>
    </message>
    <message>
        <source>Frontend fullscreen</source>
        <translation>Полноэкранный фронтенд</translation>
    </message>
    <message>
        <source>Append date and time to record file name</source>
        <translation>Указывать дату и время в названиях демок и сейвов</translation>
    </message>
    <message>
        <source>Reduced quality</source>
        <translation type="obsolete">Пониженное качество</translation>
    </message>
    <message>
        <source>Show ammo menu tooltips</source>
        <translation>Показывать подсказки к оружию</translation>
    </message>
    <message>
        <source>Enable frontend sounds</source>
        <translation>Включить звуки в меню</translation>
    </message>
    <message>
        <source>Enable frontend music</source>
        <translation>Включить музыку в меню</translation>
    </message>
    <message>
        <source>Frontend effects</source>
        <translation>Эффекты в меню</translation>
    </message>
</context>
<context>
    <name>QComboBox</name>
    <message>
        <source>generated map...</source>
        <translation>случайная карта...</translation>
    </message>
    <message>
        <source>Human</source>
        <translation>Человек</translation>
    </message>
    <message>
        <source>Level</source>
        <translation>Уровень</translation>
    </message>
    <message>
        <source>(System default)</source>
        <translation>(Системный по умолчанию)</translation>
    </message>
    <message>
        <source>generated maze...</source>
        <translation>случайный лабиринт...</translation>
    </message>
    <message>
        <source>Mission</source>
        <translation>Миссия</translation>
    </message>
    <message>
        <source>Community</source>
        <translation>Сообщество</translation>
    </message>
    <message>
        <source>Any</source>
        <translation>Любой</translation>
    </message>
    <message>
        <source>In lobby</source>
        <translation>Подготовка</translation>
    </message>
    <message>
        <source>In progress</source>
        <translation>В игре</translation>
    </message>
    <message>
        <source>Default</source>
        <translation type="obsolete">По умолчанию</translation>
    </message>
    <message>
        <source>hand drawn map...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QGroupBox</name>
    <message>
        <source>Team Members</source>
        <translation>Состав команды</translation>
    </message>
    <message>
        <source>Fort</source>
        <translation>Форт</translation>
    </message>
    <message>
        <source>Key binds</source>
        <translation>Привязки клавиш</translation>
    </message>
    <message>
        <source>Teams</source>
        <translation>Команды</translation>
    </message>
    <message>
        <source>Audio/Graphic options</source>
        <translation>Настройки звука и графики</translation>
    </message>
    <message>
        <source>Playing teams</source>
        <translation>Команды в игре</translation>
    </message>
    <message>
        <source>Net game</source>
        <translation>Сетевая игра</translation>
    </message>
    <message>
        <source>Weapons</source>
        <translation type="obsolete">Оружие</translation>
    </message>
    <message>
        <source>Game Modifiers</source>
        <translation>Модификаторы игры</translation>
    </message>
    <message>
        <source>Basic Settings</source>
        <translation>Основные настройки</translation>
    </message>
    <message>
        <source>Team Settings</source>
        <translation>Настройки команды</translation>
    </message>
    <message>
        <source>Misc</source>
        <translation>Разное</translation>
    </message>
    <message>
        <source>Schemes and Weapons</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QLabel</name>
    <message>
        <source>Mines Time</source>
        <translation>Время мин</translation>
    </message>
    <message>
        <source>Mines</source>
        <translation>Мины</translation>
    </message>
    <message>
        <source>Net nick</source>
        <translation>Имя игрока</translation>
    </message>
    <message>
        <source>This program is distributed under the GNU General Public License</source>
        <translation>Эта программа распространяется на условиях лицензии GNU (the GNU General Public License)</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>Разрешение</translation>
    </message>
    <message>
        <source>FPS limit</source>
        <translation>Ограничение FPS</translation>
    </message>
    <message>
        <source>Developers:</source>
        <translation>Разработчики:</translation>
    </message>
    <message>
        <source>Art:</source>
        <translation>Графика:</translation>
    </message>
    <message>
        <source>Translations:</source>
        <translation>Переводы:</translation>
    </message>
    <message>
        <source>Special thanks:</source>
        <translation>Особая благодарность:</translation>
    </message>
    <message>
        <source>Server name:</source>
        <translation>Название сервера:</translation>
    </message>
    <message>
        <source>Server port:</source>
        <translation>Порт:</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>Сервер:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Порт:</translation>
    </message>
    <message>
        <source>Weapons</source>
        <translation>Оружие</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Версия</translation>
    </message>
    <message>
        <source>Sounds:</source>
        <translation>Звуки:</translation>
    </message>
    <message>
        <source>Initial sound volume</source>
        <translation>Начальная громкость</translation>
    </message>
    <message>
        <source>Damage Modifier</source>
        <translation>Модификатор урона</translation>
    </message>
    <message>
        <source>Turn Time</source>
        <translation>Время хода</translation>
    </message>
    <message>
        <source>Initial Health</source>
        <translation>Начальное здоровье</translation>
    </message>
    <message>
        <source>Sudden Death Timeout</source>
        <translation>Время до скорой смерти</translation>
    </message>
    <message>
        <source>Scheme Name:</source>
        <translation>Название схемы:</translation>
    </message>
    <message>
        <source>Crate Drops</source>
        <translation>Бонус выпадает</translation>
    </message>
    <message>
        <source>Game scheme</source>
        <translation>Настройки игры</translation>
    </message>
    <message>
        <source>% Dud Mines</source>
        <translation>% невзрывающихся мин</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Название</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Тип</translation>
    </message>
    <message>
        <source>Grave</source>
        <translation>Надгробие</translation>
    </message>
    <message>
        <source>Flag</source>
        <translation>Флаг</translation>
    </message>
    <message>
        <source>Voice</source>
        <translation>Голос</translation>
    </message>
    <message>
        <source>Locale</source>
        <translation>Язык</translation>
    </message>
    <message>
        <source>Restart game to apply</source>
        <translation>Перезапустите игру для применения</translation>
    </message>
    <message>
        <source>This SVN build is &apos;work in progress&apos; and may not be compatible with other versions of the game.
Some features might be broken or incomplete. Use at your own risk!</source>
        <translation type="obsolete">This SVN build is &apos;work in progress&apos; and may not be compatible with other versions of the game.
Some features might be broken or incomplete. Use at your own risk!</translation>
    </message>
    <message>
        <source>Explosives</source>
        <translation>Взрывчатка</translation>
    </message>
    <message>
        <source>Tip: </source>
        <translation>Подсказка:</translation>
    </message>
    <message>
        <source>This development build is &apos;work in progress&apos; and may not be compatible with other versions of the game. Some features might be broken or incomplete. Use at your own risk!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Качество</translation>
    </message>
    <message>
        <source>% Health Crates</source>
        <translation>% аптечек</translation>
    </message>
    <message>
        <source>Health in Crates</source>
        <translation>Здоровье в аптечках</translation>
    </message>
    <message>
        <source>Sudden Death Water Rise</source>
        <translation>Скорость поднятия воды</translation>
    </message>
    <message>
        <source>Sudden Death Health Decrease</source>
        <translation>Скорость уменьшения здоровья</translation>
    </message>
    <message>
        <source>Bind schemes and weapons</source>
        <translation type="obsolete">Объединить настройки игры и оружия</translation>
    </message>
    <message>
        <source>% Rope Length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Gameplay</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QLineEdit</name>
    <message>
        <source>unnamed</source>
        <translation>безымянный</translation>
    </message>
</context>
<context>
    <name>QMainWindow</name>
    <message>
        <source>Hedgewars %1</source>
        <translation>Hedgewars %1</translation>
    </message>
</context>
<context>
    <name>QMessageBox</name>
    <message>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <source>Failed to open data directory:
%1
Please check your installation</source>
        <translation>Не могу найти папку с данными:
%1
Проверьте правильность установки</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Сеть</translation>
    </message>
    <message>
        <source>Connection to server is lost</source>
        <translation>Соединение с сервером потеряно</translation>
    </message>
    <message>
        <source>Weapons</source>
        <translation>Оружие</translation>
    </message>
    <message>
        <source>Can not delete default weapon set</source>
        <translation type="obsolete">Невозможно удалить набор оружия по умолчанию</translation>
    </message>
    <message>
        <source>Really delete this weapon set?</source>
        <translation>Удалить выбранный набор оружия?</translation>
    </message>
    <message>
        <source>Can not edit default weapon set</source>
        <translation type="obsolete">Невозможно редактировать набор оружия по умолчанию</translation>
    </message>
    <message>
        <source>Can not overwrite default weapon set &apos;%1&apos;!</source>
        <translation>Не могу переписать встроенный набор оружия &apos;%1&apos;!</translation>
    </message>
    <message>
        <source>All file associations have been set.</source>
        <translation>Проведено сопоставление расширений файлов.</translation>
    </message>
    <message>
        <source>File association failed.</source>
        <translation>Сопоставление не удалось.</translation>
    </message>
    <message>
        <source>Teams</source>
        <translation type="unfinished">Команды</translation>
    </message>
    <message>
        <source>Really delete this team?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Schemes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Can not delete default scheme &apos;%1&apos;!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Really delete this game scheme?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Can not delete default weapon set &apos;%1&apos;!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <source>Cannot create directory %1</source>
        <translation>Не могу создать папку %1</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>ОК</translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation>Псевдоним</translation>
    </message>
    <message>
        <source>Please enter your nickname</source>
        <translation>Пожалуйста введите ваш псевдоним</translation>
    </message>
</context>
<context>
    <name>QPushButton</name>
    <message>
        <source>Setup</source>
        <translation>Настройка</translation>
    </message>
    <message>
        <source>Play demo</source>
        <translation>Играть демку</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>Соединить</translation>
    </message>
    <message>
        <source>Go!</source>
        <translation>Вперёд!</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Старт</translation>
    </message>
    <message>
        <source>Start server</source>
        <translation>Запустить сервер</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Обновить</translation>
    </message>
    <message>
        <source>Load</source>
        <translation>Загрузить</translation>
    </message>
    <message>
        <source>Specify</source>
        <translation>Указать</translation>
    </message>
    <message>
        <source>default</source>
        <translation>по умолчанию</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Переименовать</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>ОК</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <source>Ready</source>
        <translation>Готов</translation>
    </message>
    <message>
        <source>Random Team</source>
        <translation>Случайная команда</translation>
    </message>
    <message>
        <source>Associate file extensions</source>
        <translation>Сопоставить расширения файлов</translation>
    </message>
    <message>
        <source>more</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QTableWidget</name>
    <message>
        <source>Room Name</source>
        <translation>Название</translation>
    </message>
    <message>
        <source>C</source>
        <translation>И</translation>
    </message>
    <message>
        <source>T</source>
        <translation>К</translation>
    </message>
    <message>
        <source>Owner</source>
        <translation>Главный</translation>
    </message>
    <message>
        <source>Map</source>
        <translation>Карта</translation>
    </message>
    <message>
        <source>Rules</source>
        <translation>Правила</translation>
    </message>
    <message>
        <source>Weapons</source>
        <translation>Оружие</translation>
    </message>
</context>
<context>
    <name>SelWeaponWidget</name>
    <message>
        <source>Weapon set</source>
        <translation>Набор оружия</translation>
    </message>
    <message>
        <source>Probabilities</source>
        <translation>Вероятности</translation>
    </message>
    <message>
        <source>Ammo in boxes</source>
        <translation>Оружие в ящиках</translation>
    </message>
    <message>
        <source>Delays</source>
        <translation>Задержки</translation>
    </message>
    <message>
        <source>new</source>
        <translation type="unfinished">новый</translation>
    </message>
    <message>
        <source>copy of</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TCPBase</name>
    <message>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <source>Unable to start the server: %1.</source>
        <translation>Ошибка запуска сервера: %1.</translation>
    </message>
    <message>
        <source>Unable to run engine: %1 (</source>
        <translation>Ошибка запуска движка: %1 (</translation>
    </message>
</context>
<context>
    <name>ToggleButtonWidget</name>
    <message>
        <source>Vampirism</source>
        <translation>Вампиризм</translation>
    </message>
    <message>
        <source>Karma</source>
        <translation>Карма</translation>
    </message>
    <message>
        <source>Artillery</source>
        <translation>Артиллерия</translation>
    </message>
    <message>
        <source>Fort Mode</source>
        <translation>Режим фортов</translation>
    </message>
    <message>
        <source>Divide Teams</source>
        <translation>Разделить команды</translation>
    </message>
    <message>
        <source>Solid Land</source>
        <translation>Неразрушаемая земля</translation>
    </message>
    <message>
        <source>Add Border</source>
        <translation>Добавить границу</translation>
    </message>
    <message>
        <source>Low Gravity</source>
        <translation>Низкая гравитация</translation>
    </message>
    <message>
        <source>Laser Sight</source>
        <translation>Лазерный прицел</translation>
    </message>
    <message>
        <source>Invulnerable</source>
        <translation>Неуязвимость</translation>
    </message>
    <message>
        <source>Add Mines</source>
        <translation type="obsolete">Добавить мины</translation>
    </message>
    <message>
        <source>Random Order</source>
        <translation>Случайный порядок</translation>
    </message>
    <message>
        <source>King</source>
        <translation>Король</translation>
    </message>
    <message>
        <source>Place Hedgehogs</source>
        <translation>Расставить ежей</translation>
    </message>
    <message>
        <source>Clan Shares Ammo</source>
        <translation>Общее оружие в клане</translation>
    </message>
    <message>
        <source>Disable Girders</source>
        <translation>Убрать балки</translation>
    </message>
    <message>
        <source>Disable Land Objects</source>
        <translation>Отключить дополнительные объекты</translation>
    </message>
    <message>
        <source>AI Survival Mode</source>
        <translation>Режим бессмертия ботов</translation>
    </message>
    <message>
        <source>Reset Health</source>
        <translation>Сброс уровня здоровья</translation>
    </message>
    <message>
        <source>Unlimited Attacks</source>
        <translation>Бесконечные атаки</translation>
    </message>
    <message>
        <source>Reset Weapons</source>
        <translation>Сброс оружия</translation>
    </message>
    <message>
        <source>Per Hedgehog Ammo</source>
        <translation>Индивидуальный набор оружия</translation>
    </message>
    <message>
        <source>Disable Wind</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>More Wind</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>binds</name>
    <message>
        <source>up</source>
        <translation>вверх</translation>
    </message>
    <message>
        <source>left</source>
        <translation>влево</translation>
    </message>
    <message>
        <source>right</source>
        <translation>вправо</translation>
    </message>
    <message>
        <source>down</source>
        <translation>вниз</translation>
    </message>
    <message>
        <source>attack</source>
        <translation>атака</translation>
    </message>
    <message>
        <source>put</source>
        <translation>указать</translation>
    </message>
    <message>
        <source>switch</source>
        <translation>переключить</translation>
    </message>
    <message>
        <source>slot 1</source>
        <translation>слот 1</translation>
    </message>
    <message>
        <source>slot 2</source>
        <translation>слот 2</translation>
    </message>
    <message>
        <source>slot 3</source>
        <translation>слот 3</translation>
    </message>
    <message>
        <source>slot 4</source>
        <translation>слот 4</translation>
    </message>
    <message>
        <source>slot 5</source>
        <translation>слот 5</translation>
    </message>
    <message>
        <source>slot 6</source>
        <translation>слот 6</translation>
    </message>
    <message>
        <source>slot 7</source>
        <translation>слот 7</translation>
    </message>
    <message>
        <source>slot 8</source>
        <translation>слот 8</translation>
    </message>
    <message>
        <source>timer 1 sec</source>
        <translation>таймер на 1 сек</translation>
    </message>
    <message>
        <source>timer 2 sec</source>
        <translation>таймер на 2 сек</translation>
    </message>
    <message>
        <source>timer 3 sec</source>
        <translation>таймер на 3 сек</translation>
    </message>
    <message>
        <source>timer 4 sec</source>
        <translation>таймер на 4 сек</translation>
    </message>
    <message>
        <source>timer 5 sec</source>
        <translation>таймер на 5 сек</translation>
    </message>
    <message>
        <source>capture</source>
        <translation>снимок</translation>
    </message>
    <message>
        <source>quit</source>
        <translation>выход</translation>
    </message>
    <message>
        <source>find hedgehog</source>
        <translation>найти ёжика</translation>
    </message>
    <message>
        <source>ammo menu</source>
        <translation>меню оружия</translation>
    </message>
    <message>
        <source>volume down</source>
        <translation>тише</translation>
    </message>
    <message>
        <source>volume up</source>
        <translation>громче</translation>
    </message>
    <message>
        <source>change mode</source>
        <translation>сменить режим</translation>
    </message>
    <message>
        <source>pause</source>
        <translation>пауза</translation>
    </message>
    <message>
        <source>slot 9</source>
        <translation>слот 9</translation>
    </message>
    <message>
        <source>hedgehogs
info</source>
        <translation>информация
о ежах</translation>
    </message>
    <message>
        <source>chat</source>
        <translation>чат</translation>
    </message>
    <message>
        <source>chat history</source>
        <translation>история чата</translation>
    </message>
    <message>
        <source>confirmation</source>
        <translation>подтверждение</translation>
    </message>
    <message>
        <source>precise aim</source>
        <translation>точное наведение</translation>
    </message>
    <message>
        <source>zoom in</source>
        <translation>увеличить</translation>
    </message>
    <message>
        <source>zoom out</source>
        <translation>уменьшить</translation>
    </message>
    <message>
        <source>reset zoom</source>
        <translation>сбросить увеличение</translation>
    </message>
    <message>
        <source>long jump</source>
        <translation>прыжок в длину</translation>
    </message>
    <message>
        <source>high jump</source>
        <translation>прыжок в высоту</translation>
    </message>
    <message>
        <source>slot 10</source>
        <translation>слот 10</translation>
    </message>
</context>
<context>
    <name>binds (categories)</name>
    <message>
        <source>Basic controls</source>
        <translation>Основное управление</translation>
    </message>
    <message>
        <source>Weapon controls</source>
        <translation>Управление оружием</translation>
    </message>
    <message>
        <source>Camera and cursor controls</source>
        <translation>Управление камерой и курсором</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Разное</translation>
    </message>
</context>
<context>
    <name>binds (descriptions)</name>
    <message>
        <source>Move your hogs and aim:</source>
        <translation>Передвижение ежа и прицеливание:</translation>
    </message>
    <message>
        <source>Traverse gaps and obstacles by jumping:</source>
        <translation>Прохождение оврагов и препятствий прыжками:</translation>
    </message>
    <message>
        <source>Fire your selected weapon or trigger an utility item:</source>
        <translation>Выстрел из выбранного оружия или активация утилиты:</translation>
    </message>
    <message>
        <source>Pick a weapon or a target location under the cursor:</source>
        <translation>Выбор оружия или цели под курсором:</translation>
    </message>
    <message>
        <source>Switch your currently active hog (if possible):</source>
        <translation>Переключение вашего активного ежа (если возможно):</translation>
    </message>
    <message>
        <source>Pick a weapon or utility item:</source>
        <translation>Подбор оружия или утилиты:</translation>
    </message>
    <message>
        <source>Set the timer on bombs and timed weapons:</source>
        <translation>Установка таймера на бомбы и оружие с таймером:</translation>
    </message>
    <message>
        <source>Move the camera to the active hog:</source>
        <translation>Передвижение камеры на активного ежа:</translation>
    </message>
    <message>
        <source>Move the cursor or camera without using the mouse:</source>
        <translation>Перемещение курсора или камеры без использования мыши:</translation>
    </message>
    <message>
        <source>Modify the camera&apos;s zoom level:</source>
        <translation>Изменение уровня увеличения камеры:</translation>
    </message>
    <message>
        <source>Talk to your team or all participants:</source>
        <translation>Разговор с командой или всеми участниками:</translation>
    </message>
    <message>
        <source>Pause, continue or leave your game:</source>
        <translation>Пауза, продолжение или выход из игры:</translation>
    </message>
    <message>
        <source>Modify the game&apos;s volume while playing:</source>
        <translation>Изменение громкости в течение игры:</translation>
    </message>
    <message>
        <source>Toggle fullscreen mode:</source>
        <translation>Переключение полноэкранного режима:</translation>
    </message>
    <message>
        <source>Take a screenshot:</source>
        <translation>Создание скриншота:</translation>
    </message>
    <message>
        <source>Toggle labels above hedgehogs:</source>
        <translation>Переключение меток над ежами:</translation>
    </message>
</context>
<context>
    <name>binds (keys)</name>
    <message>
        <source>Axis</source>
        <translation>Ось</translation>
    </message>
    <message>
        <source>(Up)</source>
        <translation>(Вверх)</translation>
    </message>
    <message>
        <source>(Down)</source>
        <translation>(Вниз)</translation>
    </message>
    <message>
        <source>Hat</source>
        <translation>Шляпа</translation>
    </message>
    <message>
        <source>(Left)</source>
        <translation>(Влево)</translation>
    </message>
    <message>
        <source>(Right)</source>
        <translation>(Вправо)</translation>
    </message>
    <message>
        <source>Button</source>
        <translation>Кнопка</translation>
    </message>
    <message>
        <source>Keyboard</source>
        <translation>Клавиатура</translation>
    </message>
    <message>
        <source>Mouse: Left button</source>
        <translation>Мышь: Левая кнопка</translation>
    </message>
    <message>
        <source>Mouse: Middle button</source>
        <translation>Мышь: Средняя кнопка</translation>
    </message>
    <message>
        <source>Mouse: Right button</source>
        <translation>Мышь: Правая кнопка</translation>
    </message>
    <message>
        <source>Mouse: Wheel up</source>
        <translation>Мышь: Колесо вверх</translation>
    </message>
    <message>
        <source>Mouse: Wheel down</source>
        <translation>Мышь: Колесо вниз</translation>
    </message>
    <message>
        <source>Backspace</source>
        <translation>Забой</translation>
    </message>
    <message>
        <source>Tab</source>
        <translation>Tab</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Очистить</translation>
    </message>
    <message>
        <source>Return</source>
        <translation>Return</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Пауза</translation>
    </message>
    <message>
        <source>Escape</source>
        <translation>Escape</translation>
    </message>
    <message>
        <source>Space</source>
        <translation>Пробел</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Delete</translation>
    </message>
    <message>
        <source>Up</source>
        <translation>Вверх</translation>
    </message>
    <message>
        <source>Down</source>
        <translation>Вниз</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Вправо</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Влево</translation>
    </message>
    <message>
        <source>Right shift</source>
        <translation>Правый shift</translation>
    </message>
    <message>
        <source>Left shift</source>
        <translation>Левый shift</translation>
    </message>
    <message>
        <source>Right ctrl</source>
        <translation>Правый ctrl</translation>
    </message>
    <message>
        <source>Left ctrl</source>
        <translation>Левый ctrl</translation>
    </message>
    <message>
        <source>Right alt</source>
        <translation>Правый alt</translation>
    </message>
    <message>
        <source>Left alt</source>
        <translation>Левый alt</translation>
    </message>
    <message>
        <source>Numpad 0</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Numpad 1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Numpad 2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Numpad 3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Numpad 4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Numpad 5</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Numpad 6</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Numpad 7</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Numpad 8</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Numpad 9</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Numpad .</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Numpad /</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Numpad *</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Numpad -</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Numpad +</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enter</source>
        <translation>Ввод</translation>
    </message>
    <message>
        <source>Equals</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Insert</source>
        <translation>Insert</translation>
    </message>
    <message>
        <source>Home</source>
        <translation>Home</translation>
    </message>
    <message>
        <source>End</source>
        <translation>End</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>Page up</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>Page down</translation>
    </message>
    <message>
        <source>Num lock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Caps lock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scroll lock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right meta</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left meta</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A button</source>
        <translation>Кнопка A</translation>
    </message>
    <message>
        <source>B button</source>
        <translation>Кнопка B</translation>
    </message>
    <message>
        <source>X button</source>
        <translation>Кнопка X</translation>
    </message>
    <message>
        <source>Y button</source>
        <translation>Кнопка Y</translation>
    </message>
    <message>
        <source>LB button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RB button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Back button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left stick</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right stick</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left stick (Right)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left stick (Left)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left stick (Down)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left stick (Up)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left trigger</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right trigger</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right stick (Down)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right stick (Up)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right stick (Right)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right stick (Left)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DPad</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
